import PINRemoteImage
import SnapKit
import UIKit

class ViewController: UIViewController {
    override func viewDidLoad() {
        super.viewDidLoad()
        
        let stack = UIStackView(); stack.axis = .vertical
        
        let staticImageButton = UIButton(type: .system)
        let staticGifButton = UIButton(type: .system)
        let downloadedImageButton = UIButton(type: .system)
        let downloadedGifButton = UIButton(type: .system)
        
        stack.addArrangedSubview(staticImageButton)
        stack.addArrangedSubview(staticGifButton)
        stack.addArrangedSubview(downloadedImageButton)
        stack.addArrangedSubview(downloadedGifButton)
        
        staticImageButton.setTitle("Static image", for: .normal)
        staticGifButton.setTitle("Static gif", for: .normal)
        downloadedImageButton.setTitle("Downloaded image", for: .normal)
        downloadedGifButton.setTitle("Downloaded gif", for: .normal)
        
        staticImageButton.addTarget(self, action: #selector(pressedStaticImage), for: .touchUpInside)
        staticGifButton.addTarget(self, action: #selector(pressedStaticGif), for: .touchUpInside)
        downloadedImageButton.addTarget(self, action: #selector(pressedDownloadedImage), for: .touchUpInside)
        downloadedGifButton.addTarget(self, action: #selector(pressedDownloadedGif), for: .touchUpInside)
        
        self.view.addSubview(stack)
        stack.snp.makeConstraints { make in
            make.centerY.left.right.equalToSuperview()
        }
    }
    
    private func openPhotoViewer(object: PhotoViewerViewController.Object) {
        let vc = PhotoViewerViewController(viewerObject: object)
        vc.modalPresentationStyle = .overFullScreen
        
        self.present(vc, animated: true, completion: nil)
    }
    
    @objc private func pressedStaticImage() {
        let image = #imageLiteral(resourceName: "static-image")
        self.openPhotoViewer(object: .image(image))
    }
    
    @objc private func pressedStaticGif() {
        guard let path = Bundle.main.path(forResource: "static-gif", ofType: "gif") else {
            return
        }
        
        let url = URL(fileURLWithPath: path)
        guard let data = try? Data(contentsOf: url), let image = PINCachedAnimatedImage(animatedImageData: data) else {
            return
        }
        
        self.openPhotoViewer(object: .animatedImage(image))
    }
    
    @objc private func pressedDownloadedImage() {
        let string = "https://i.imgur.com/BwmPZQ0.jpg"
        self.openPhotoViewer(object: .urlString(string))
    }
    
    @objc private func pressedDownloadedGif() {
        let string = "https://i.imgur.com/0PuBxQ1.gif"
        self.openPhotoViewer(object: .urlString(string))
    }
}
